/*
 *    GeoTools - The Open Source Java GIS Toolkit
 *    http://geotools.org
 *
 *    (C) 2011, Open Source Geospatial Foundation (OSGeo)
 *    (C) 2003-2005, Open Geospatial Consortium Inc.
 *
 *    All Rights Reserved. http://www.opengis.org/legal/
 */
package org.opengis.referencing.crs;

import static org.opengis.annotation.Obligation.*;
import static org.opengis.annotation.Specification.*;

import org.opengis.annotation.UML;
import org.opengis.referencing.cs.AffineCS;
import org.opengis.referencing.datum.ImageDatum;

/**
 * An engineering coordinate reference system applied to locations in images. Image coordinate
 * reference systems are treated as a separate sub-type because a separate user community exists for
 * images with its own terms of reference.
 *
 * <TABLE CELLPADDING='6' BORDER='1'>
 * <TR BGCOLOR="#EEEEFF"><TH NOWRAP>Used with CS type(s)</TH></TR>
 * <TR><TD>
 *   {@link org.opengis.referencing.cs.CartesianCS Cartesian},
 *   {@link org.opengis.referencing.cs.AffineCS    Affine}
 * </TD></TR></TABLE>
 *
 * @source $URL$
 * @version <A HREF="http://portal.opengeospatial.org/files/?artifact_id=6716">Abstract
 *     specification 2.0</A>
 * @author Martin Desruisseaux (IRD)
 * @since GeoAPI 1.0
 */
@UML(identifier = "SC_ImageCRS", specification = ISO_19111)
public interface ImageCRS extends SingleCRS {
    /** Returns the cartesian coordinate system. */
    @UML(
        identifier = "usesObliqueCartesianCS, usesCartesianCS",
        obligation = MANDATORY,
        specification = ISO_19111
    )
    AffineCS getCoordinateSystem();

    /** Returns the datum, which must be an image one. */
    @UML(identifier = "usesDatum", obligation = MANDATORY, specification = ISO_19111)
    ImageDatum getDatum();
}
