/*
 *    GeoTools - The Open Source Java GIS Toolkit
 *    http://geotools.org
 *
 *    (C) 2011, Open Source Geospatial Foundation (OSGeo)
 *    (C) 2003-2005, Open Geospatial Consortium Inc.
 *
 *    All Rights Reserved. http://www.opengis.org/legal/
 */
package org.opengis.referencing.crs;

import static org.opengis.annotation.Obligation.*;
import static org.opengis.annotation.Specification.*;

import org.opengis.annotation.UML;
import org.opengis.referencing.cs.CoordinateSystem;
import org.opengis.referencing.datum.Datum;

/**
 * Abstract coordinate reference system, consisting of a single {@linkplain CoordinateSystem
 * Coordinate System} and a single {@linkplain Datum Datum} (as opposed to {@linkplain CompoundCRS
 * Compound CRS}).
 *
 * <p>A coordinate reference system consists of an ordered sequence of coordinate system axes that
 * are related to the earth through a datum. A coordinate reference system is defined by one datum
 * and by one coordinate system. Most coordinate reference system do not move relative to the earth,
 * except for engineering coordinate reference systems defined on moving platforms such as cars,
 * ships, aircraft, and spacecraft.
 *
 * <p>Coordinate reference systems are commonly divided into sub-types. The common classification
 * criterion for sub-typing of coordinate reference systems is the way in which they deal with earth
 * curvature. This has a direct effect on the portion of the earth's surface that can be covered by
 * that type of CRS with an acceptable degree of error. The exception to the rule is the subtype
 * "Temporal" which has been added by analogy.
 *
 * @source $URL$
 * @version <A HREF="http://portal.opengeospatial.org/files/?artifact_id=6716">Abstract
 *     specification 2.0</A>
 * @author Martin Desruisseaux (IRD)
 * @since GeoAPI 2.0
 * @see org.opengis.referencing.cs.CoordinateSystem
 * @see org.opengis.referencing.datum.Datum
 */
@UML(identifier = "SC_SingleCRS", specification = ISO_19111)
public interface SingleCRS extends CoordinateReferenceSystem {
    /**
     * Returns the coordinate system.
     *
     * @rename Expanded the "CS" abbreviation into "CoordinateSystem".
     */
    @UML(identifier = "usesCS", obligation = MANDATORY, specification = ISO_19111)
    CoordinateSystem getCoordinateSystem();

    /**
     * Returns the datum.
     *
     * @return The datum.
     */
    @UML(identifier = "usesDatum", obligation = MANDATORY, specification = ISO_19111)
    Datum getDatum();
}
